<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>MX Package Installer</source>
        <translation>Instalador e Desinstalador de Programas do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Programas Aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Informações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="468"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="1030"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Instalador e Desinstalador de Programas Aplicativos do MX Linux&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Este programa é um gerenciador de pacotes do MX Linux, o nome original em idioma Inglês é ‘&lt;b&gt;MX Package Installer&lt;/b&gt;’. &lt;br&gt;Os itens sombreados ou esmaecidos indicam que os programas aplicativos já estão instalados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="730"/>
        <location filename="../mainwindow.ui" line="1055"/>
        <location filename="../mainwindow.ui" line="1274"/>
        <source>search</source>
        <translation>Digite aqui para pesquisar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="772"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>= Installed packages</source>
        <translation>= Pacotes instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Enabled Repos</source>
        <translation>Repositórios Ativados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Remove orphan packages</source>
        <translation>Remover os pacotes órfãos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <location filename="../mainwindow.ui" line="1337"/>
        <source>Upgrade All</source>
        <translation>Atualizar Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.ui" line="558"/>
        <location filename="../mainwindow.ui" line="886"/>
        <source>Installed:</source>
        <translation>Instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="907"/>
        <source>Total packages:</source>
        <translation>Total de pacotes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="615"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Instalar também os pacotes “recomendados”</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="879"/>
        <source>Upgradable:</source>
        <translation>Atualizáveis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <location filename="../mainwindow.ui" line="522"/>
        <location filename="../mainwindow.ui" line="914"/>
        <source>Hide library and developer packages</source>
        <translation>Ocultar os pacotes das bibliotecas e os pacotes do desenvolvedor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Refresh list</source>
        <translation>Atualizar a lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <location filename="../mainwindow.ui" line="688"/>
        <location filename="../mainwindow.ui" line="1085"/>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar os pacotes de acordo com o seu estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <location filename="../mainwindow.ui" line="397"/>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="695"/>
        <location filename="../mainwindow.ui" line="1088"/>
        <location filename="../mainwindow.ui" line="1092"/>
        <location filename="../mainwindow.cpp" line="2645"/>
        <source>All packages</source>
        <translation>Todos os pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <location filename="../mainwindow.ui" line="700"/>
        <location filename="../mainwindow.ui" line="1097"/>
        <location filename="../mainwindow.cpp" line="2657"/>
        <source>Installed</source>
        <translation>Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <location filename="../mainwindow.ui" line="705"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <location filename="../mainwindow.cpp" line="2656"/>
        <source>Upgradable</source>
        <translation>Atualizáveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1107"/>
        <location filename="../mainwindow.ui" line="1234"/>
        <location filename="../mainwindow.cpp" line="2625"/>
        <location filename="../mainwindow.cpp" line="2658"/>
        <location filename="../mainwindow.cpp" line="2773"/>
        <location filename="../mainwindow.cpp" line="2774"/>
        <source>Not installed</source>
        <translation>Não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <location filename="../mainwindow.ui" line="752"/>
        <location filename="../mainwindow.ui" line="814"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Pacote atualizável. A versão mais recente está disponível no repositório selecionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Package Name</source>
        <translation>Nome do Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <location filename="../mainwindow.ui" line="1469"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>Repositório de Teste do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="796"/>
        <source>Debian Backports</source>
        <translation>Repositório Retroportado do Debian (Backports)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1142"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1148"/>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>For all users</source>
        <translation>Para todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>For current user</source>
        <translation>Para o usuário atual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Remote (repo):</source>
        <translation>Repositório remoto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.ui" line="1204"/>
        <location filename="../mainwindow.cpp" line="2605"/>
        <source>All apps</source>
        <translation>Todos os aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.cpp" line="2610"/>
        <source>All runtimes</source>
        <translation>Todas as versões</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1214"/>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>All available</source>
        <translation>Todos os disponíveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1219"/>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>Installed apps</source>
        <translation>Aplicativos Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <location filename="../mainwindow.cpp" line="2601"/>
        <source>Installed runtimes</source>
        <translation>Versões dos pacotes instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1229"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <location filename="../mainwindow.cpp" line="2766"/>
        <location filename="../mainwindow.cpp" line="2767"/>
        <source>All installed</source>
        <translation>Todos instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1316"/>
        <source>Total items </source>
        <translation>Total de itens:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1330"/>
        <source>Installed apps:</source>
        <translation>Aplicativos instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1413"/>
        <source>Total installed size:</source>
        <translation>Espaço utilizado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1427"/>
        <source>Remove unused runtimes</source>
        <translation>Remover as versões que não estiverem sendo utilizadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1459"/>
        <source>Short Name</source>
        <translation>Nome Resumido</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1464"/>
        <source>Full Package Name</source>
        <translation>Nome Completo do Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1504"/>
        <location filename="../mainwindow.cpp" line="2390"/>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>Console Output</source>
        <translation>Resultados no Console/Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1510"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1521"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responda aqui ou apenas pressione a tecla ‘Enter’</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1580"/>
        <location filename="../mainwindow.cpp" line="1101"/>
        <location filename="../mainwindow.cpp" line="2760"/>
        <location filename="../mainwindow.cpp" line="2763"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1587"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1606"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1609"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1616"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1696"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1706"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1722"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1729"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Flatpak tab is disabled on 32-bit.</source>
        <translation>A aba ou guia ‘Flatpak’ está desativada para 32 bits.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Could not find MX sources.</source>
        <translation>Não foi possível encontrar as fontes do MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Uninstalling packages...</source>
        <translation>Desinstalando os pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Executando as operações da pré-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Running post-uninstall operations...</source>
        <translation>Executando as operações da pós-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <source>Refreshing sources...</source>
        <translation>Atualizando as fontes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <location filename="../mainwindow.cpp" line="1149"/>
        <location filename="../mainwindow.cpp" line="1278"/>
        <location filename="../mainwindow.cpp" line="1430"/>
        <location filename="../mainwindow.cpp" line="1493"/>
        <location filename="../mainwindow.cpp" line="1805"/>
        <location filename="../mainwindow.cpp" line="1929"/>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2255"/>
        <location filename="../mainwindow.cpp" line="2366"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2439"/>
        <location filename="../mainwindow.cpp" line="2467"/>
        <location filename="../mainwindow.cpp" line="2487"/>
        <location filename="../mainwindow.cpp" line="2851"/>
        <location filename="../mainwindow.cpp" line="2925"/>
        <location filename="../mainwindow.cpp" line="2955"/>
        <location filename="../mainwindow.cpp" line="3050"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Houve um problema ao atualizar as fontes/origens. Algumas fontes podem não ter fornecido atualizações. Para obter mais informação, verifique:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Please wait...</source>
        <translation>Por favor, espere...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>Version </source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source> in the enabled repos</source>
        <translation>nos repositórios ativados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Not available in the enabled repos</source>
        <translation>Não está disponível nos repositórios que estão ativados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Latest version </source>
        <translation>Última versão </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source> already installed</source>
        <translation>já está instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source> installed</source>
        <translation>instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Você está prestes a utilizar o Repositório de Testes do MX que disponibiliza os pacotes apenas para teste. É possível que eles quebrem/danifiquem o seu sistema operacional. Por isso, é recomendado que você faça uma cópia de segurança (backup) do seu sistema operacional e instale ou atualize apenas um pacote de cada vez. Se for possível, nos informe no fórum, como foi a sua experiência com o pacote, para que ele seja avaliado e encaminhado para o repositório principal (estável) se for qualificado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Você está prestes a utilizar o repositório do ‘Debian Backports’ (atualizações retroportadas), que contém pacotes retirados do próximo lançamento do Debian (chamado de ‘teste’ ou ‘testing’), adaptados e recompilados para o uso na versão atual do Debian ‘estável’ ou ‘stable’. Estes pacotes não foram testados tão extensivamente como os das versões estáveis do Debian e do MX Linux, são fornecidos no estado em que se encontram ou ‘como estão’, possuem o risco de incompatibilidades com outros componentes do Debian estável. Por tanto, utilize com muito cuidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="991"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>O repositório do MX Linux inclui os pacotes do tipo ‘Flatpaks’, são destinados apenas para a facilitar o acesso dos usuários a este tipo de pacote. Nós não somos responsáveis pelo funcionamento dos pacotes do tipo ‘Flatpaks’. Para obter mais informações, por favor, consulte ‘Flatpaks’ no Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="999"/>
        <location filename="../mainwindow.cpp" line="3059"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Do not show this message again</source>
        <translation>Não exibir esta mensagem novamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Os seguintes pacotes foram selecionados. Clique na opção ‘Exibir Detalhes‘ para exibir a lista de alterações.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1150"/>
        <location filename="../mainwindow.cpp" line="1279"/>
        <location filename="../mainwindow.cpp" line="1494"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Sem conexão com a internet, não será possível baixar/descarregar/transferir a lista de pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1153"/>
        <source>Installing packages...</source>
        <translation>Instalando os pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1208"/>
        <source>Post-processing...</source>
        <translation>Pós-processamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1240"/>
        <source>Pre-processing for </source>
        <translation>Pré-processamento para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1255"/>
        <source>Installing </source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>Post-processing for </source>
        <translation>Pós-processamento para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ocorreu um erro ao escrever ou gravar o arquivo %1. Por favor, verifique se você tem espaço livre suficiente no seu dispositivo de armazenamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1502"/>
        <source>Downloading package info...</source>
        <translation>Baixando as informações do pacote...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <location filename="../mainwindow.cpp" line="1930"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation>O comando ‘dpkg’ reportou um erro. Por favor, execute o comando ‘dpkg --list’ no emulador de terminal e verifique o resultado da saída.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2005"/>
        <location filename="../mainwindow.cpp" line="2087"/>
        <location filename="../mainwindow.cpp" line="2110"/>
        <source>Package info</source>
        <translation>Informações do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2017"/>
        <location filename="../mainwindow.cpp" line="2992"/>
        <source>More &amp;info...</source>
        <translation>Mais &amp;informações...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2048"/>
        <source>Packages to be installed: </source>
        <translation>Pacotes a serem instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Processing finished successfully.</source>
        <translation>O processamento foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2244"/>
        <location filename="../mainwindow.cpp" line="2256"/>
        <location filename="../mainwindow.cpp" line="2852"/>
        <location filename="../mainwindow.cpp" line="2926"/>
        <location filename="../mainwindow.cpp" line="2956"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Foi detectado um problema durante a instalação, por favor, verifique as informações de saída no Console/Terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2266"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2267"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2269"/>
        <source>Package Installer for MX Linux</source>
        <translation>Instalador e Desinstalador de Programas do MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2271"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2272"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2284"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2366"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Ocorreu um problema ao desinstalar o pacote, por favor, verifique o resultado do processo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Success</source>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Ocorreu um problema ao desinstalar o programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2440"/>
        <location filename="../mainwindow.cpp" line="2468"/>
        <location filename="../mainwindow.cpp" line="2488"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Não foi possível baixar a lista de pacotes atualizada. Por favor, verifique as suas fontes do APT na pasta /etc/apt/sources.list.d.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2520"/>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak not installed</source>
        <translation>O Flatpak não está instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2521"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>O pacote Flatpak não está instalado.
Você gostaria de instalá-lo agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak was not installed</source>
        <translation>O Flatpak não foi instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2558"/>
        <source>Needs re-login</source>
        <translation>É preciso sair da sessão e entrar novamente com o seu usuário e senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2559"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Você pode precisar sair da sessão e entrar novamente com o seu usuário e senha para ver os novos itens instalados nos menus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2760"/>
        <source>Upgrade</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2880"/>
        <source>Quit?</source>
        <translation>Você quer sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2881"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>O processo ainda está em execução, se você finalizar agora pode deixar o seu sistema operacional em um estado inutilizável.&lt;p&gt;&lt;b&gt;Você tem certeza que quer fechar o Instalador e Desinstalador de Programas do MX?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3026"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3051"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Um problema foi detectado durante a última operação. Por favor, inspecione a saída do Console/Terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3060"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>A operação é potencialmente perigosa.
Por favor, verifique cuidadosamente a lista de pacotes a ser removida.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gerenciar os Repositórios Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Para todos os usuários</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Para este usuário</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>digite o endereço do repositório Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>digite o endereço Flatpakref para instalar um aplicativo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Adicione ou remova os repositórios flatpak, ou instale aplicativos utilizando o endereço flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Remover o repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Adicionar o repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Instalar o aplicativo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Não é removível</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>O Flathub é o repositório principal dos Flatpak’s e não pode ser removido</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="95"/>
        <source>Error adding remote</source>
        <translation>Ocorreu um erro ao adicionar o repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Não foi possível adicionar o repositório - o comando retornou um erro. Por favor, verifique o endereço do repositório e tente novamente.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>O repositório foi adicionado com sucesso</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>O banco de dados do dpkg/apt está bloqueado por outro programa: %1
Feche o outro programa gerenciador de pacotes ou espere até que o processamento termine e tente novamente.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>O Instalador e Desinstalador de Programas do MX, o nome original em idioma Inglês é ‘MX Package Installer’, é uma ferramenta utilizada para gerenciar os aplicativos ou pacotes no MX Linux
    - instala programas aplicativos de diferentes fontes
    - instala programas aplicativos do repositório de teste MX
    - instala programas aplicativos do repositório retroportado do Debian (Backports)
    - instala programas aplicativos com o formato Flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Ignorar a verificação de conexão com a internet se for relatado falsamente de que não há conexão com a internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <location filename="../main.cpp" line="103"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando com o usuário ‘root’ (administrador). Por favor, saia da sessão e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>You must run this program with admin access.</source>
        <translation>Você tem que executar este programa com o usuário administrador.</translation>
    </message>
</context>
</TS>
